@@ -4,10 +4,10 @@ import SparseArrays
 import DiffEqBase: NAN_CHECK, INFINITE_OR_GIANT
 
 function NAN_CHECK(x::SparseArrays.AbstractSparseMatrixCSC)
-    any(NAN_CHECK, SparseArrays.nonzeros(x))
+    return any(NAN_CHECK, SparseArrays.nonzeros(x))
 end
 function INFINITE_OR_GIANT(x::SparseArrays.AbstractSparseMatrixCSC)
-    any(INFINITE_OR_GIANT, SparseArrays.nonzeros(x))
+    return any(INFINITE_OR_GIANT, SparseArrays.nonzeros(x))
 end
 
 end
