@@ -12,7 +12,7 @@ using Distributions
 @test DiffEqBase.promote_tspan((0, 1)) == (0, 1)
 @test DiffEqBase.promote_tspan(nothing, nothing, (0, 1), nothing, (dt = 1,)) == (0, 1)
 @test DiffEqBase.promote_tspan(nothing, nothing, (0, 1), nothing, (dt = 1 / 2,)) ==
-      (0.0, 1.0)
+    (0.0, 1.0)
 
 prob = ODEProblem((u, p, t) -> u, (p, t0) -> p[1], (p) -> (0.0, p[2]), (2.0, 1.0))
 prob2 = DiffEqBase.get_concrete_problem(prob, true)
@@ -37,11 +37,12 @@ prob = ODEProblem((u, p, t) -> u, 1.0, (0, 1))
 prob2 = DiffEqBase.get_concrete_problem(prob, true)
 @test prob2.tspan == (0.0, 1.0)
 
-prob = DDEProblem((u, h, p, t) -> -h(p, t - p[1]), (p, t0) -> p[2], (p, t) -> 0,
-    (p) -> (0.0, p[3]), (1.0, 2.0, 3.0); constant_lags = (p) -> [p[1]])
+prob = DDEProblem(
+    (u, h, p, t) -> -h(p, t - p[1]), (p, t0) -> p[2], (p, t) -> 0,
+    (p) -> (0.0, p[3]), (1.0, 2.0, 3.0); constant_lags = (p) -> [p[1]]
+)
 prob2 = DiffEqBase.get_concrete_problem(prob, true)
 
 @test prob2.u0 == 2.0
 @test prob2.tspan == (0.0, 3.0)
 @test prob2.constant_lags == [1.0]
-
